@@ -609,9 +609,13 @@ class CronTask(models.Model):
 
             import os
             import time
-            run_sql(mysql_config, '''delete from  cap_runlog  where tid=%s and type='cron' and rid < \
-             (select min(rid) from ( select rid  from cap_runlog where \
-                  tid=%s and type='cron' order by rid desc limit  100) t)''', (tid, tid))
+            try:
+                run_sql(mysql_config, '''delete from  cap_runlog  where tid=%s and type='cron' and rid < \
+                 (select min(rid) from ( select rid  from cap_runlog where \
+                      tid=%s and type='cron' order by rid desc limit  100) t)''', (tid, tid))
+            except:
+                time.sleep(3)
+                pass
             rid = run_sql(mysql_config, "insert into cap_runlog(tid,`type`,repo_url,version,addtime,begintime,status,stdout,stderror) \
                              values(%s,'cron',%s,%s,unix_timestamp(now()),unix_timestamp(now()),1,'','')",
                           (tid, repo_url, version))
@@ -984,13 +988,16 @@ class DeamonTask(models.Model):
                 return lastrowid
 
             import os
-            run_sql(mysql_config, '''delete from  cap_runlog  where tid=%s and type='deamon' and rid < \
-                         (select min(rid) from ( select rid  from cap_runlog where \
-                              tid=%s and type='deamon' order by rid desc limit  100) t)''', (tid, tid))
+            import time
+            try:
+                run_sql(mysql_config, '''delete from  cap_runlog  where tid=%s and type='deamon' and rid < \
+                             (select min(rid) from ( select rid  from cap_runlog where \
+                                  tid=%s and type='deamon' order by rid desc limit  100) t)''', (tid, tid))
+            except:
+                time.sleep(3)
             rid = run_sql(mysql_config, "insert into cap_runlog(tid,`type`,repo_url,version,addtime,begintime,status,stdout,stderror) \
                                  values(%s,'deamon',%s,%s,unix_timestamp(now()),unix_timestamp(now()),1,'','')",
                           (tid, repo_url, version))
-            import time
             time.sleep(0.8)
             run_sql(mysql_config, "update cap_deamontask set runlog_rid=%s,run_times=run_times+1 where tid=%s",
                     (rid, tid))
